<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=zh
// ** ne pas modifier le fichier **

return [

	// A
	'access_interface_graphique' => '返回完整显示模式',
	'access_mode_texte' => '显示简洁显示模式',
	'admin_debug' => '除錯',
	'admin_modifier_article' => '修改文章',
	'admin_modifier_auteur' => '修改作者',
	'admin_modifier_breve' => '修改简要',
	'admin_modifier_mot' => '修改关键词',
	'admin_modifier_rubrique' => '修改此栏',
	'admin_recalculer' => '刷新页面',
	'afficher_trad' => '显示译文',
	'alerte_maj_impossible' => '<b>警告!</b> 更新SQL到版本 @version@失败, 可能是数据库权限问题. 请联系您的ISP(INTERNET服务提供商) .', # MODIF
	'alerte_modif_info_concourante' => '注意:这条信息在别处被更改。目前值为 :', # MODIF
	'analyse_xml' => 'XML分析',
	'annuler' => '取消',
	'antispam_champ_vide' => '请保留此格空白:',
	'articles_recents' => '最新文章',
	'avis_archive_incorrect' => '打包文件不是有效的SPIP文件',
	'avis_archive_invalide' => '打包文件无效',
	'avis_attention' => '注意!',
	'avis_champ_incorrect_type_objet' => '无效名 @name@ 对象名 @type@',
	'avis_colonne_inexistante' => ' @col@ 列不存在',
	'avis_erreur' => '错误: 参见以下',
	'avis_erreur_connexion' => '连接失败',
	'avis_erreur_cookie' => 'cookie错误',
	'avis_erreur_fonction_contexte' => '程序失败. 该功能不能在此调用.', # MODIF
	'avis_erreur_mysql' => 'SQL错误', # MODIF
	'avis_erreur_sauvegarde' => '@type@ @id_objet@备份失败!',
	'avis_erreur_visiteur' => '访问个人空间出错',

	// B
	'barre_a_accent_grave' => '插入加重的字符',
	'barre_aide' => '用象征图快捷定义展出',
	'barre_e_accent_aigu' => '插入加重的E ',
	'barre_eo' => '插入oe [法文输入]',
	'barre_eo_maj' => '在O之后插入E[法文OE输入]',
	'barre_euro' => '插入欧元标志€',
	'barre_gras' => '置为{{黑体}}',
	'barre_guillemets' => '加双引号',
	'barre_guillemets_simples' => '加单引号',
	'barre_intertitre' => '转为{{{小标题}}}',
	'barre_italic' => '置为{斜体}',
	'barre_lien' => '转为超文本链接[http://...]',
	'barre_lien_input' => '请输入目标链接(您可以使用 http://www.mysite.com的格式或直接指出在本站中该文章的编号).',
	'barre_note' => '转为[[页尾标号]]',
	'barre_paragraphe' => '新建段落', # MODIF
	'barre_quote' => '<quote>引用一个消息</quote>',
	'bouton_changer' => '修改',
	'bouton_chercher' => '搜索',
	'bouton_choisir' => '选择',
	'bouton_enregistrer' => '保存',
	'bouton_radio_desactiver_messagerie_interne' => '停用内部消息',
	'bouton_radio_envoi_annonces' => '发送可编辑的声明',
	'bouton_radio_non_envoi_annonces' => '不使用任何声明',
	'bouton_radio_non_envoi_liste_nouveautes' => '不发送最近新闻列表',
	'bouton_recharger_page' => '重载本页',
	'bouton_telecharger' => '上传',
	'bouton_upload' => '上传', # MODIF
	'bouton_valider' => '提交',

	// C
	'cal_apresmidi' => '下午',
	'cal_jour_entier' => '整日',
	'cal_matin' => '早晨',
	'cal_par_jour' => '按日显示日程',
	'cal_par_mois' => '按月显示日程',
	'cal_par_semaine' => '按周显示日程',
	'choix_couleur_interface' => '颜色',
	'choix_interface' => '界面切换', # MODIF
	'colonne' => '列',
	'confirm_changer_statut' => '注意，您要求改变这一项目的状态。请确认继续。',
	'correcte' => '生效', # MODIF

	// D
	'date_aujourdhui' => '今天',
	'date_avant_jc' => '公元前',
	'date_dans' => '在 @delai@之内。',
	'date_de_mois_1' => '@nommois@@j@日',
	'date_de_mois_10' => '@nommois@@j@日',
	'date_de_mois_11' => '@nommois@@j@日',
	'date_de_mois_12' => '@nommois@@j@日',
	'date_de_mois_2' => '@nommois@@j@日',
	'date_de_mois_3' => '@nommois@@j@日',
	'date_de_mois_4' => '@nommois@@j@日',
	'date_de_mois_5' => '@nommois@@j@日',
	'date_de_mois_6' => '@nommois@@j@日',
	'date_de_mois_7' => '@nommois@@j@日',
	'date_de_mois_8' => '@nommois@@j@日',
	'date_de_mois_9' => '@nommois@@j@日',
	'date_demain' => '明天',
	'date_fmt_heures_minutes' => '@h@:@m@',
	'date_fmt_jour_heure' => '@jour@@heure@时',
	'date_fmt_jour_mois' => '@nommois@@jour@日',
	'date_fmt_jour_mois_annee' => '@annee@年@nommois@@jour@日',
	'date_fmt_mois_annee' => '@annee@年@nommois@',
	'date_fmt_nomjour_date' => '@nomjour@ 日@date@',
	'date_heures' => '小时',
	'date_hier' => '昨天',
	'date_il_y_a' => ' @delai@以前',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => '星期日',
	'date_jour_1_abbr' => '周日',
	'date_jour_1_initiale' => '星期天',
	'date_jour_2' => '星期一',
	'date_jour_2_abbr' => '周一',
	'date_jour_2_initiale' => 'l.',
	'date_jour_3' => '星期二',
	'date_jour_3_abbr' => '星期二',
	'date_jour_3_initiale' => '二',
	'date_jour_4' => '星期三',
	'date_jour_4_abbr' => '周三',
	'date_jour_4_initiale' => '三',
	'date_jour_5' => '星期四',
	'date_jour_5_abbr' => '周四',
	'date_jour_5_initiale' => '四',
	'date_jour_6' => '星期五',
	'date_jour_6_abbr' => '周五',
	'date_jour_6_initiale' => '五',
	'date_jour_7' => '星期六',
	'date_jour_7_abbr' => '周六',
	'date_jour_7_initiale' => '六',
	'date_jours' => '天',
	'date_minutes' => '分钟',
	'date_mois' => '月',
	'date_mois_1' => '1月',
	'date_mois_10' => '10月',
	'date_mois_10_abbr' => '十月',
	'date_mois_11' => '11月',
	'date_mois_11_abbr' => '十一月',
	'date_mois_12' => '12月',
	'date_mois_12_abbr' => '十二月',
	'date_mois_1_abbr' => '一月',
	'date_mois_2' => '2月',
	'date_mois_2_abbr' => '二月',
	'date_mois_3' => '3月',
	'date_mois_3_abbr' => '三月',
	'date_mois_4' => '4月',
	'date_mois_4_abbr' => '四月',
	'date_mois_5' => '5月',
	'date_mois_5_abbr' => '五月',
	'date_mois_6' => '6月',
	'date_mois_6_abbr' => '六月',
	'date_mois_7' => '7月',
	'date_mois_7_abbr' => '七月',
	'date_mois_8' => '8月',
	'date_mois_8_abbr' => '八月',
	'date_mois_9' => '9月',
	'date_mois_9_abbr' => '九月',
	'date_saison_1' => '冬季',
	'date_saison_2' => '春季',
	'date_saison_3' => '夏季',
	'date_saison_4' => '秋季',
	'date_semaines' => '周',
	'dirs_commencer' => '为了开始安装',
	'dirs_preliminaire' => '初步: <b>设置访问权限</b>',
	'dirs_probleme_droits' => '访问权限问题', # MODIF
	'dirs_repertoires_absents' => '<b>未找到下列目录: <ul>@bad_dirs@.</ul> </b>
<p>可能由于输入大小写有误.
请确认目录的大小写正确; 如果不正确, 可通过FTP软件修改目录名字以纠错.<p>一旦完成,您可以', # MODIF
	'dirs_repertoires_suivants' => '<b>以下目录无写权限: <ul>@bad_dirs@.</ul> </b>

  <p>修改权限请使用FTP客户端为每个目录设定访问权限. 该操作在用户指南中有详细介绍.

  <p>一旦完成,您可以', # MODIF

	// E
	'envoi_via_le_site' => '通过本网站发送',

	// F
	'fichier_introuvable' => '找不到@fichier@文件', # MODIF
	'form_deja_inscrit' => '您已注册.',
	'form_email_non_valide' => '您的电子邮件无效.',
	'form_forum_access_refuse' => '您无权继续访问该站点.',
	'form_forum_bonjour' => '您好@nom@，', # MODIF
	'form_forum_email_deja_enregistre' => '该电子邮件地址已经记录,您可以使用常用密码.',
	'form_forum_identifiant_mail' => '您的新标识已经通过邮件发送给您了.',
	'form_forum_identifiants' => '个人标识符',
	'form_forum_indiquer_nom_email' => '输入您的名字和电子邮件地址,您将很快通过电子邮件获取您的个人标识符.',
	'form_forum_login' => '登录:',
	'form_forum_message_auto' => '(这是自动消息)',
	'form_forum_pass' => '密码:',
	'form_forum_probleme_mail' => '邮件问题: 标识符不能被发送.',
	'form_forum_voici1' => '这是您加入站点网站编辑和论坛的标识符 "@nom_site_spip@" (@adresse_site@):', # MODIF
	'form_forum_voici2' => '这是您提交文章的标识符
"@nom_site_spip@" (@adresse_login@):', # MODIF
	'form_indiquer_email' => '请输入您的电子邮件地址.',
	'form_indiquer_nom' => '请输入您的名字.',
	'form_indiquer_nom_site' => '请输入您的站点名字.',
	'form_pet_deja_enregistre' => '站点已经注册',
	'form_pet_signature_pasprise' => '签名被忽略.',
	'form_prop_confirmer_envoi' => '确认发送',
	'form_prop_description' => '描述/注释',
	'form_prop_enregistre' => '你的提议已经被记录, 站点管理员使它有效它将在线显示.', # MODIF
	'form_prop_envoyer' => '发送消息',
	'form_prop_indiquer_email' => '请输入有效的电子邮件地址',
	'form_prop_indiquer_nom_site' => '请输入站点名',
	'form_prop_indiquer_sujet' => '请输入标题',
	'form_prop_message_envoye' => '消息发送',
	'form_prop_non_enregistre' => '您的提议未被记录.',
	'form_prop_sujet' => '标题',
	'form_prop_url_site' => '站点URL', # MODIF
	'forum_non_inscrit' => '可能您还没有注册或者您输入的地址或密码错误.',
	'forum_par_auteur' => '按 @auteur@',
	'forum_titre_erreur' => '错误...',

	// I
	'ical_texte_rss_articles' => '本站点文章的«引用»文件地址:',
	'ical_texte_rss_articles2' => '您同样可以获得站点中各个专栏下文章的«引用»文件:',
	'ical_texte_rss_breves' => '存在多个站点简要的文件.通过指出专栏编号,您可以获得仅与该专栏相关的简要.',
	'icone_a_suivre' => '跟踪',
	'icone_admin_site' => '站点管理',
	'icone_agenda' => '记事',
	'icone_aide_ligne' => '帮助', # MODIF
	'icone_articles' => '文章',
	'icone_auteurs' => '作者',
	'icone_brouteur' => '快速浏览',
	'icone_configuration_site' => '配置', # MODIF
	'icone_configurer_site' => '配置站点',
	'icone_creer_nouvel_auteur' => '新建一个作者',
	'icone_creer_rubrique' => '新建专栏',
	'icone_creer_sous_rubrique' => '新建子专栏',
	'icone_deconnecter' => '断开连接',
	'icone_discussions' => '讨论',
	'icone_doc_rubrique' => '各专栏文档',
	'icone_ecrire_article' => '写新文章',
	'icone_edition_site' => '编辑', # MODIF
	'icone_gestion_langues' => '语言管理',
	'icone_informations_personnelles' => '个人信息',
	'icone_interface_complet' => '完整界面',
	'icone_interface_simple' => '简单界面',
	'icone_maintenance_site' => '站点维护',
	'icone_messagerie_personnelle' => '个人消息',
	'icone_repartition_debut' => '显示从开始的分布',
	'icone_rubriques' => '专栏',
	'icone_sauver_site' => '站点备份',
	'icone_site_entier' => '整个站点',
	'icone_sites_references' => '参考站点',
	'icone_statistiques' => '站点统计',
	'icone_suivi_activite' => '跟踪站点的活动',
	'icone_suivi_actualite' => '站点评估',
	'icone_suivi_pettions' => '跟踪/管理请求',
	'icone_suivi_revisions' => '文章修改',
	'icone_supprimer_document' => '删除文档',
	'icone_supprimer_image' => '删除图片',
	'icone_tous_articles' => '您所有的文章',
	'icone_tous_auteur' => '所有作者',
	'icone_visiter_site' => '访问', # MODIF
	'icone_voir_en_ligne' => '在线预览',
	'img_indisponible' => '必需图像',
	'info_a_suivre' => '跟踪 »',
	'info_acces_interdit' => '访问禁止',
	'info_acces_refuse' => '访问拒绝',
	'info_action' => '动作: @action@',
	'info_administrer_rubriques' => '您可以管理该专栏及其子专栏',
	'info_adresse_non_indiquee' => '您没有指定测试地址!',
	'info_aide' => '帮助:',
	'info_ajouter_mot' => '添加关键词',
	'info_annonce' => '声明',
	'info_annonces_generales' => '一般声明:',
	'info_article_propose' => '已提交的文章',
	'info_article_publie' => '已发表的文章',
	'info_article_redaction' => '进展中的文章',
	'info_article_refuse' => '丢弃的文章',
	'info_article_supprime' => '删除的文章',
	'info_articles' => '文章',
	'info_articles_a_valider' => '需要确认的文章',
	'info_articles_proposes' => '提交的文章',
	'info_auteurs_nombre' => '作者:',
	'info_authentification_ftp' => '(通过 FTP)验证.',
	'info_breves_2' => '简要',
	'info_connexion_refusee' => '连接禁止',
	'info_contact_developpeur' => '请联系开发者.', # MODIF
	'info_contenance' => '站点包括:',
	'info_contribution' => '论坛投稿', # MODIF
	'info_copyright' => '@spip@是一款免费软件@lien_gpl@。',
	'info_copyright_doc' => '详细信息,请访问站点 <a href="@spipnet@">http://www.spip.net/zh</a>.', # MODIF
	'info_copyright_gpl' => '根据GPL协议',
	'info_cours_edition' => '进展中文章', # MODIF
	'info_creer_repertoire' => '请创建一个文件或目录叫:',
	'info_creer_repertoire_2' => '在<b>@repertoire@</b>子目录内部，然后 ：',
	'info_creer_vignette' => '自动产生图标',
	'info_deplier' => '展开',
	'info_descriptif_nombre' => '描述:',
	'info_description' => '描述:',
	'info_description_2' => '描述:',
	'info_dimension' => '大小:',
	'info_ecire_message_prive' => '写一个私有信息',
	'info_email_invalide' => '无论电子邮件地址.',
	'info_en_cours_validation' => '进展中的文章',
	'info_en_ligne' => '现在在线:',
	'info_envoyer_message_prive' => '给作者发一个私有信息',
	'info_erreur_requete' => '错误查询:',
	'info_erreur_squelette2' => '所有面板<b>@fichier@</b>均无效...',
	'info_erreur_systeme' => '系统错误 (errno @errsys@)',
	'info_erreur_systeme2' => '硬盘无足够空间,或数据库遭破坏。<br />
<span style="color:red;">请试用 <a href=\'@script@\'>修复数据库</a>，
 或者联系您的管理员。</span>', # MODIF
	'info_fini' => '完成了!',
	'info_format_image' => '图片格式被用来创建插图: @gd_formats@.',
	'info_format_non_defini' => '未定义格式',
	'info_grand_ecran' => '大图显示',
	'info_image_aide' => '帮助',
	'info_image_process_titre' => '生成图标的方法',
	'info_impossible_lire_page' => '<b>错误!</b>通过代理服务，此页不能阅读<tt><html>@test_proxy@</html></tt>',
	'info_installation_systeme_publication' => '公众系统安装 ...',
	'info_installer_documents' => '您可以自动安装 @upload@ 中所有文件。',
	'info_installer_ftp' => '作为管理员，您可安装(通过 FTP)@upload@中文件使得以后能从这儿选择.', # MODIF
	'info_installer_images' => '你可安装的图片格式 JPEG, GIF 及其它 PNG.',
	'info_installer_images_dossier' => '安装@upload@目录中的图片以便在这里可以选择他们。',
	'info_interface_complete' => '完整界面',
	'info_interface_simple' => '简单界面 ',
	'info_joindre_document_article' => '你可附上你的文章的附加文档的类型',
	'info_joindre_document_rubrique' => '您可加入该栏的文档类型',
	'info_joindre_documents_article' => '你可附上你文章的附加文档的类型:',
	'info_l_article' => '文章',
	'info_la_breve' => '新闻',
	'info_la_rubrique' => '专栏',
	'info_langue_principale' => '主站点语言',
	'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ 像素', # MODIF
	'info_les_auteurs_1' => '按 @les_auteurs@',
	'info_logo_format_interdit' => '仅@formats@格式之文件被允许作标志',
	'info_logo_max_poids' => 'Les logos doivent obligatoirement faire moins de @maxi@ (ce fichier fait @actuel@).',
	'info_mail_fournisseur' => 'you@isp.com',
	'info_message_2' => '消息',
	'info_message_supprime' => '删除的消息',
	'info_mise_en_ligne' => '在线出版物的日期:',
	'info_modification_parametres_securite' => '修改安全参数',
	'info_mois_courant' => '在月中:',
	'info_mot_cle_ajoute' => '下列关键被加进',
	'info_multi_herit' => '缺省语言',
	'info_multi_langues_soulignees' => '<u>加下划线的语言</u> 提供了所有界面的语言的翻译. 如果你选择语言, 公共站点的所有元素 (日期, 论坛) 将被自动翻译. 作为没有下划线的语言, 这些元素将出现在站点的主语言界面上.', # MODIF
	'info_multilinguisme' => '多语言',
	'info_nom_non_utilisateurs_connectes' => '你的名字不显示在连接用户的列表中.', # MODIF
	'info_nom_utilisateurs_connectes' => '你的名字显示在连接用户的列表中.', # MODIF
	'info_nombre_en_ligne' => '现在在线:',
	'info_non_resultat' => ' "@cherche_mot@"没有结果',
	'info_non_utilisation_messagerie' => '你没有使用站点内部消息.',
	'info_nouveau_message' => '你有新消息',
	'info_nouveaux_messages' => '你有 @total_messages@ 条新消息',
	'info_numero_abbreviation' => '第 ',
	'info_pense_bete' => '忘备',
	'info_petit_ecran' => '小图显示',
	'info_pixels' => '像素',
	'info_plusieurs_mots_trouves' => '几个关键词找到了 "@cherche_mot@":',
	'info_portfolio_automatique' => '自动相册:',
	'info_premier_resultat' => '[@debut_limit@ 最新结果出了 @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ 最新结果出了@total@]',
	'info_propose_1' => '[@nom_site_spip@] 提交: @titre@',
	'info_propose_2' => '提交文章
-----------------',
	'info_propose_3' => '文章 "@titre@" 提交给公众.',
	'info_propose_4' => '你被邀请预览它发表你的观念',
	'info_propose_5' => '在论坛中连向它. 在地址中可用到:',
	'info_publie_01' => '文章 "@titre@" 被 @connect_nom@确认.',
	'info_publie_1' => '[@nom_site_spip@] 出版: @titre@',
	'info_publie_2' => '出版的文章
-----------------',
	'info_rechercher' => '搜索',
	'info_rechercher_02' => '搜索:',
	'info_remplacer_vignette' => '用定制的图标取代缺省的图标:',
	'info_sans_titre_2' => '无标题',
	'info_selectionner_fichier' => '从@upload@文件中选择一个文件', # MODIF
	'info_selectionner_fichier_2' => '选择一个文件:',
	'info_supprimer_vignette' => '删除小插图',
	'info_symbole_bleu' => '<b>蓝色</b>标志<b>备注</b>：例如个人使用的消息.', # MODIF
	'info_symbole_jaune' => '<b>黄色</b>表示<b>对所有编辑者声明</b> ：所有站点管理者都能看见并编辑。', # MODIF
	'info_symbole_vert' => '<b>绿色</b>表示<b>站点中与其它用户交换的信息</b>。', # MODIF
	'info_telecharger_nouveau_logo' => '上传新图标:',
	'info_telecharger_ordinateur' => '从你的电脑上传:',
	'info_tous_resultats_enregistres' => '[所有结果被记录]',
	'info_tout_afficher' => '显示所有',
	'info_travaux_texte' => '站点还未建立. 请稍后再来...',
	'info_travaux_titre' => '站点正在施工中',
	'info_trop_resultat' => ' "@cherche_mot@"有太多结果; 请重定义搜索.',
	'info_utilisation_messagerie_interne' => '你正使用站点的内部消息.',
	'info_valider_lien' => '使连接有效',
	'info_verifier_image' => ', 请确定你的图片已正确传送.',
	'info_vignette_defaut' => '缺省的小插图',
	'info_vignette_personnalisee' => '定制小插图',
	'info_visite' => '访问:',
	'info_vos_rendez_vous' => '将来的约会',
	'infos_vos_pense_bete' => '备注', # MODIF

	// L
	'lien_afficher_icones_seuls' => '只显示图片',
	'lien_afficher_texte_icones' => '显示文本和图片',
	'lien_afficher_texte_seul' => '只显示正文',
	'lien_liberer' => '发表',
	'lien_liberer_tous' => '释放这些文章', # MODIF
	'lien_nouvea_pense_bete' => '新备注',
	'lien_nouveau_message' => '新消息',
	'lien_nouvelle_annonce' => '新声明',
	'lien_petitions' => '请求',
	'lien_popularite' => '普及: @popularite@%',
	'lien_racine_site' => '站点根',
	'lien_reessayer' => '重试',
	'lien_repondre_message' => '回应消息',
	'lien_supprimer' => '删除',
	'lien_tout_afficher' => '显示所有',
	'lien_visite_site' => '访问站点',
	'lien_visites' => '@visites@ 访问',
	'lien_voir_auteur' => '检查作者',
	'login_acces_prive' => '访问私有区',
	'login_autre_identifiant' => '用另一个标识符',
	'login_cookie_accepte' => '请设定你的浏览器接受它们 (至少是这个站点a).',
	'login_cookie_oblige' => '为安全的标识你,你必须接受cookies.',
	'login_deconnexion_ok' => '已断开连接.',
	'login_erreur_pass' => '密码错.',
	'login_espace_prive' => '私有区',
	'login_identifiant_inconnu' => '标识符 "@login@" 不可认.',
	'login_login' => '登录:',
	'login_login2' => '登录(连接到站点的标识符):', # MODIF
	'login_login_pass_incorrect' => '(错误的登录和密码).',
	'login_motpasseoublie' => '忘记密码?',
	'login_non_securise' => '警告, 论坛不安全.
   如果你不愿自己的密码中途侦听到
   , 请激活你浏览器的 Javascript
   并且',
	'login_nouvelle_tentative' => '新尝试',
	'login_par_ici' => '你已注册... 这种方法...',
	'login_pass2' => '密码:',
	'login_preferez_refuser' => '<b>如果你更愿意拒绝 cookies</b>, 有其它的连接方法 (安全性要低一些) :',
	'login_recharger' => '重载该页',
	'login_rester_identifie' => '保留登录几天', # MODIF
	'login_retour_public' => '返回公共站点',
	'login_retour_site' => '返回公共站点',
	'login_retoursitepublic' => '返回公共站点',
	'login_sinscrire' => '注册', # MODIF
	'login_test_navigateur' => '测试浏览/重新连接',
	'login_verifiez_navigateur' => '(无论如何, 请确认你的浏览器不会记住你的密码...)',

	// M
	'module_fichiers_langues' => '语言文件',

	// N
	'navigateur_pas_redirige' => '如果您的浏览器没有跳转,请按这里继续.',

	// O
	'onglet_affacer_base' => '删除数据库',
	'onglet_auteur' => '作者',
	'onglet_contenu_site' => '站点内容',
	'onglet_evolution_visite_mod' => '评估',
	'onglet_fonctions_avances' => '高级功能',
	'onglet_informations_personnelles' => '个人信息',
	'onglet_interactivite' => '互动',
	'onglet_messagerie' => '消息',
	'onglet_repartition_rubrique' => '按专栏发布',
	'onglet_save_restaur_base' => '备份/恢复数据库',
	'onglet_vider_cache' => '清空缓存',

	// P
	'pass_choix_pass' => '请选择新密码:',
	'pass_erreur' => '错误',
	'pass_erreur_acces_refuse' => '<b>错误:</b> 你再也无权访问站点.',
	'pass_erreur_code_inconnu' => '<b>错误:</b> 代码不符合任何有站点访问权的访问者.', # MODIF
	'pass_erreur_non_enregistre' => '<b>错误 :</b> 地址<tt>@email_oubli@</tt> 未在站点注册.',
	'pass_erreur_non_valide' => '<b>错误 :</b> 电子邮件 <tt>@email_oubli@</tt> 无效!',
	'pass_erreur_probleme_technique' => '<b>错误 :</b> 电子邮件由于技术原因不能发送.',
	'pass_espace_prive_bla' => '注册后站点的私有区对访问者开放
. 一旦注册,
你可以预览进展中的文章,
提交文章参与所有的论坛.', # MODIF
	'pass_forum_bla' => '你已请求参与论坛
注册访问者保留区.', # MODIF
	'pass_indiquez_cidessous' => '在以下输入你以前注册的电子邮件地址
.你
将收到电子邮件
向你解释如何得到访问.',
	'pass_mail_passcookie' => '(这是自动消息)
要重新访问站点
@nom_site_spip@ (@adresse_site@)

请到以下地址:

    @sendcookie@

您可以输入新密码
重新连接到站点。

', # MODIF
	'pass_mot_oublie' => '忘记密码',
	'pass_nouveau_enregistre' => '你的新密码已经被记录.',
	'pass_nouveau_pass' => '新密码',
	'pass_ok' => '好',
	'pass_oubli_mot' => '忘记密码',
	'pass_quitter_fenetre' => '退出窗口',
	'pass_rappel_login' => '记住: 你的标识符(登录) 是 "@login@".',
	'pass_recevoir_mail' => '你将收到电子邮件解释如何访问站点.', # MODIF
	'pass_retour_public' => '返回公众站点',
	'pass_rien_a_faire_ici' => '这里无事可作.',
	'pass_vousinscrire' => '登记站点',
	'precedent' => '前一个',
	'previsualisation' => '预览',
	'previsualiser' => '预览',

	// S
	'stats_visites_et_popularite' => '@visites@ 访问者; 流行: @popularite@',
	'suivant' => '后一个',

	// T
	'taille_ko' => '@taille@ kb',
	'taille_mo' => '@taille@ Mb',
	'taille_octets' => '@taille@字符',
	'taille_octets_bi' => '@taille@字符',
	'texte_actualite_site_1' => '当您认为此界面适合您，您就可以点击«', # MODIF
	'texte_actualite_site_2' => '完整界西',
	'texte_actualite_site_3' => '» 使更多特性可用.',
	'texte_creation_automatique_vignette' => '站点自动创建签名预览激活. 如果你安装, 通过论坛, 图片格式 @gd_formats@, 它们将能和一个最大尺寸为 @taille_preview@ 像素的连接.',
	'texte_documents_associes' => '以下文档与文章相关联,,
    但是它们不是直接插入的
    . 基于公共站点的规划,
    它们将作为附和文档出现.',
	'texte_erreur_mise_niveau_base' => '整理过程中数据库错误。
图像<b>@fichier@</b>不能通过 (article @id_article@)。
认真阅读此参考内容，
再试整理过程，
并注意图像始终显示在你的文件中。', # MODIF
	'texte_inc_auth_1' => '用登录名标识你自己
  <b>@auth_login@</b>, 但是在数据库中不存在 (不再存在). 
  试', # MODIF
	'texte_inc_auth_2' => '重新连接',
	'texte_inc_auth_3' => '退出然后
  重新启动你的浏览器.',
	'texte_inc_config' => '以下的输入的修改显著的影响了站点的功能
  . 仔细它除非你熟悉SPIP系统的功能
  . <br /><br /><b>更一般地
 , 强烈建议你的WEB站点管理员
 处理这页.</b>', # MODIF
	'texte_inc_meta_1' => '系统再写入文件<code>@fichier@</code>时遇到错误。作为站点管理员请', # MODIF
	'texte_inc_meta_2' => '确认写权限', # MODIF
	'texte_inc_meta_3' => '目录 ecrire/ 之上', # MODIF
	'texte_statut_en_cours_redaction' => '编辑中',
	'texte_statut_poubelle' => '到垃圾箱',
	'texte_statut_propose_evaluation' => '提交评估',
	'texte_statut_publie' => '在线出版',
	'texte_statut_refuse' => '丢弃',
	'titre_ajouter_mot_cle' => '加关键字:',
	'titre_cadre_raccourcis' => '快捷方式:',
	'titre_changer_couleur_interface' => '改变界面颜色',
	'titre_image_admin_article' => '你可以管理这篇文章',
	'titre_image_administrateur' => '管理者', # MODIF
	'titre_image_aide' => '该项目的帮助',
	'titre_image_auteur_supprime' => '删除的作者',
	'titre_image_redacteur' => '不能访问的编辑者',
	'titre_image_redacteur_02' => '编辑者',
	'titre_image_visiteur' => '访问者',
	'titre_joindre_document' => '附加文档',
	'titre_mots_cles' => '关键词',
	'titre_probleme_technique' => '警告:技术问题 MYSQL 制止访问站点的这部分,谢谢理解 .', # MODIF
	'titre_publier_document' => '在此栏下发布文档',
	'titre_signatures_attente' => '签名等待认证', # MODIF
	'titre_statistiques' => '站点统计',
	'titre_titre_document' => '文章标题:',
	'trad_reference' => '(参考文章)', # MODIF

	// Z
	'zbug_code' => '代码',
	'zbug_erreur_boucle_double' => '环@id@: 重复定义', # MODIF
	'zbug_erreur_boucle_fermant' => '环@id@: 缺少语句结尾标志', # MODIF
	'zbug_erreur_boucle_syntaxe' => '句法中出现错误的环', # MODIF
	'zbug_erreur_filtre' => '错误: 过滤<b>« @filtre@ »</b>未定义', # MODIF
	'zbug_info_erreur_squelette' => '站点错误',
	'zbug_table_inconnue' => 'SQL表格 « @table@ » 未知',
];
